@@ -166,6 +166,22 @@ test!(
     "#
 );
 
+test!(
+    join,
+    r#"
+    ([], {}, [0,null,false,true,"abc"], {a:0,b:null,c:false,d:true,e:"abc"}) | join(",")
+    "#,
+    r#"
+    null
+    "#,
+    r#"
+    ""
+    ""
+    "0,,false,true,abc"
+    "0,,false,true,abc"
+    "#
+);
+
 test!(
     limit_infinite_stream,
     r#"
@@ -586,3 +602,36 @@ test!(
     "err"
     "#
 );
+
+test!(
+    string_format_sh,
+    r#"
+    @sh "\(0, "a b c", [0,null,true,"a b c"])"
+    "#,
+    r#"
+    null
+    "#,
+    r#"
+    "0"
+    "'a b c'"
+    "0 null true 'a b c'"
+    "#
+);
+
+test!(
+    format,
+    r#"
+    format("html", "uri", "csv", "tsv", "sh", "base64")
+    "#,
+    r#"
+    [1,2,3]
+    "#,
+    r#"
+    "[1,2,3]"
+    "%5B1%2C2%2C3%5D"
+    "1,2,3"
+    "1\t2\t3"
+    "1 2 3"
+    "WzEsMiwzXQ=="
+    "#
+);
